@@ -30,6 +30,7 @@ import shutil
 import fnmatch
 import distutils.sysconfig
 import codecs
+import subprocess
 
 # Define the globals.
 progName = None
@@ -37,6 +38,7 @@ currDir = os.getcwd()
 modDir = None
 pyModDir = None
 platBinDir = None
+platBinDirOld = None
 distDir = None
 apisDir = None
 installApis = True
@@ -173,7 +175,10 @@ def usage(rcode=2):
     print("    -y         add the Python variant to the executable names")
     print("    -z         don't compile the installed python files")
     print("    --pyqt=version version of PyQt to be used (one of 4 or 5)")
-    print("                   (default: {0})".format(pyqtVariant[-1]))
+    if pyqtVariant:
+        print("                   (default: {0})".format(pyqtVariant[-1]))
+    else:
+        print("                   (no PyQt variant found)")
     print()
     print("The file given to the -f option must be valid Python code"
           " defining a")
@@ -222,12 +227,16 @@ def initGlobals():
     Module function to set the values of globals that need more than a
     simple assignment.
     """
-    global platBinDir, modDir, pyModDir, apisDir, pyqtVariant
+    global platBinDir, modDir, pyModDir, apisDir, pyqtVariant, platBinDirOld
 
     if sys.platform.startswith("win"):
         platBinDir = sys.exec_prefix
         if platBinDir.endswith("\\"):
             platBinDir = platBinDir[:-1]
+        platBinDirOld = platBinDir
+        platBinDir = os.path.join(platBinDir, "Scripts")
+        if not os.path.exists(platBinDir):
+            platBinDir = platBinDirOld
     else:
         platBinDir = "/usr/local/bin"
 
@@ -480,7 +489,7 @@ def cleanUp():
     """
     Uninstall the old eric files.
     """
-    global platBinDir, includePythonVariant
+    global platBinDir, platBinDirOld, includePythonVariant
     
     try:
         from eric6config import getConfig
@@ -526,8 +535,11 @@ def cleanUp():
         rem_wnames = [n + marker for n in rem_wnames]
     
     try:
+        dirs = [platBinDir, getConfig('bindir')]
+        if platBinDirOld:
+            dirs.append(platBinDirOld)
         for rem_wname in rem_wnames:
-            for d in [platBinDir, getConfig('bindir')]:
+            for d in dirs:
                 rwname = wrapperName(d, rem_wname)
                 if os.path.exists(rwname):
                     os.remove(rwname)
@@ -846,7 +858,8 @@ def createMacAppBundle(pydir):
     @param pydir the name of the directory where the Python script will
         eventually be installed (string)
     """
-    global cfg, sourceDir, macAppBundleName, macPythonExe, macAppBundlePath
+    global cfg, sourceDir, macAppBundleName, macPythonExe, macAppBundlePath, \
+        pyqtVariant
     
     dirs = {
         "contents": "{0}/{1}/Contents/".format(
@@ -867,23 +880,36 @@ def createMacAppBundle(pydir):
         starter = "python{0}".format(sys.version_info.major)
     
     wname = os.path.join(dirs["exe"], "eric6")
+    
+    # determine entry for DYLD_FRAMEWORK_PATH
+    dyldLine = ""
+    try:
+        if pyqtVariant == "PyQt4":
+            from PyQt4.QtCore import QLibraryInfo
+        else:
+            from PyQt5.QtCore import QLibraryInfo
+        qtLibraryDir = QLibraryInfo.location(QLibraryInfo.LibrariesPath)
+    except ImportError:
+        qtLibraryDir = ""
+    if qtLibraryDir:
+        dyldLine = "DYLD_FRAMEWORK_PATH={0}\n".format(qtLibraryDir)
+    
+    # determine entry for PATH
+    pathLine = ""
     path = os.getenv("PATH", "")
     if path:
         pybin = os.path.join(sys.exec_prefix, "bin")
         pathlist = path.split(os.pathsep)
         if pybin not in pathlist:
-            pathlist.insert(0, pybin)
-        path = os.pathsep.join(pathlist)
-        wrapper = ('''#!/bin/sh\n'''
-                   '''\n'''
-                   '''PATH={0}\n'''
-                   '''exec "{1}" "{2}/{3}.py" "$@"\n'''
-                   .format(path, starter, pydir, "eric6"))
-    else:
-        wrapper = ('''#!/bin/sh\n'''
-                   '''\n'''
-                   '''exec "{0}" "{1}/{2}.py" "$@"\n'''
-                   .format(starter, pydir, "eric6"))
+            pathLine = "PATH={0}{1}{2}\n".format(pybin, os.pathsep, path)
+        else:
+            pathLine = "PATH={0}\n".format(path)
+    wrapper = ('''#!/bin/sh\n'''
+               '''\n'''
+               '''{0}'''
+               '''{1}'''
+               '''exec "{2}" "{3}/{4}.py" "$@"\n'''
+               .format(pathLine, dyldLine, starter, pydir, "eric6"))
     copyToFile(wname, wrapper)
     os.chmod(wname, 0o755)
     
@@ -1033,6 +1059,7 @@ def doDependancyChecks():
     print('Checking dependencies')
     
     # perform dependency checks
+    print("Python Version: {0:d}.{1:d}.{2:d}".format(*sys.version_info[:3]))
     if sys.version_info < (2, 7, 0):
         print('Sorry, you must have Python 2.7.0 or higher or '
               'Python 3.1.0 or higher.')
@@ -1043,7 +1070,6 @@ def doDependancyChecks():
     if sys.version_info > (3, 9, 9):
         print('Sorry, eric6 requires Python 3 or Python 2 for running.')
         exit(5)
-    print("Python Version: {0:d}.{1:d}.{2:d}".format(*sys.version_info[:3]))
     
     try:
         import xml.etree            # __IGNORE_WARNING__
@@ -1116,18 +1142,19 @@ def doDependancyChecks():
     # check version of Qt
     qtMajor = int(qVersion().split('.')[0])
     qtMinor = int(qVersion().split('.')[1])
+    print("Qt Version: {0}".format(qVersion().strip()))
     if qtMajor < 4 or \
         (qtMajor == 4 and qtMinor < 8) or \
             (qtMajor == 5 and qtMinor < 3):
         print('Sorry, you must have Qt version 4.8.0 or better or')
         print('5.3.0 or better.')
         exit(2)
-    print("Qt Version: {0}".format(qVersion()))
     
     # check version of sip
     try:
         import sip
         sipVersion = sip.SIP_VERSION_STR
+        print("sip Version:", sipVersion.strip())
         # always assume, that snapshots are new enough
         if "snapshot" not in sipVersion:
             while sipVersion.count('.') < 2:
@@ -1158,6 +1185,7 @@ def doDependancyChecks():
     else:
         from PyQt5.QtCore import PYQT_VERSION_STR
     pyqtVersion = PYQT_VERSION_STR
+    print("PyQt Version:", pyqtVersion.strip())
     # always assume, that snapshots are new enough
     if "snapshot" not in pyqtVersion:
         while pyqtVersion.count('.') < 2:
@@ -1180,7 +1208,6 @@ def doDependancyChecks():
                       .format(vers))
                 print('Please install another version.')
                 exit(4)
-    print("PyQt Version: ", pyqtVersion)
     
     # check version of QScintilla
     if pyqtVariant == "PyQt4":
@@ -1188,6 +1215,7 @@ def doDependancyChecks():
     else:
         from PyQt5.Qsci import QSCINTILLA_VERSION_STR
     scintillaVersion = QSCINTILLA_VERSION_STR
+    print("QScintilla Version:", QSCINTILLA_VERSION_STR.strip())
     # always assume, that snapshots are new enough
     if "snapshot" not in scintillaVersion:
         while scintillaVersion.count('.') < 2:
@@ -1209,7 +1237,7 @@ def doDependancyChecks():
                     ' eric6.'.format(vers))
                 print('Please install another version.')
                 exit(5)
-    print("QScintilla Version: ", QSCINTILLA_VERSION_STR)
+    
     print("All dependencies ok.")
     print()
 
@@ -1311,6 +1339,42 @@ def compileUiFiles():
     compileUiDir(sourceDir, True, pyName)
 
 
+def prepareInfoFile(fileName):
+    """
+    Function to prepare an Info.py file when installing from source.
+    
+    @param fileName name of the Python file containing the info (string)
+    """
+    if not fileName:
+        return
+    
+    try:
+        os.rename(fileName, fileName + ".orig")
+    except EnvironmentError:
+        pass
+    try:
+        hgOut = subprocess.check_output(["hg", "identify", "-i"])
+        if sys.version_info[0] == 3:
+            hgOut = hgOut.decode()
+    except (OSError, subprocess.CalledProcessError):
+        hgOut = ""
+    if hgOut:
+        hgOut = hgOut.strip()
+        if hgOut.endswith("+"):
+            hgOut = hgOut[:-1]
+        if sys.version_info[0] == 2:
+            f = codecs.open(fileName + ".orig", "r", "utf-8")
+        else:
+            f = open(fileName + ".orig", "r", encoding="utf-8")
+        text = f.read()
+        f.close()
+        text = text.replace("@@REVISION@@", hgOut)\
+            .replace("@@VERSION@@", "rev_" + hgOut)
+        copyToFile(fileName, text)
+    else:
+        shutil.copy(fileName + ".orig", fileName)
+
+
 def main(argv):
     """
     The main function of the script.
@@ -1399,10 +1463,15 @@ def main(argv):
         elif "--noapis":
             installApis = False
     
+    infoName = ""
     installFromSource = not os.path.isdir(sourceDir)
     if installFromSource:
         sourceDir = os.path.dirname(__file__) or "."
         configName = os.path.join(sourceDir, "eric6config.py")
+        if os.path.exists(os.path.join(sourceDir, ".hg")):
+            # we are installing from source with repo
+            infoName = os.path.join(sourceDir, "UI", "Info.py")
+            prepareInfoFile(infoName)
     
     if len(cfg) == 0:
         createInstallConfig()
@@ -1487,6 +1556,15 @@ def main(argv):
             os.rename(configName + ".orig", configName)
     except EnvironmentError:
         pass
+    try:
+        if installFromSource and infoName:
+            os.remove(infoName)
+            infoNameC = infoName + 'c'
+            if os.path.exists(infoNameC):
+                os.remove(infoNameC)
+            os.rename(infoName + ".orig", infoName)
+    except EnvironmentError:
+        pass
     
     print("\nInstallation complete.")
     print()
